@@ -224,19 +224,19 @@ class Deployer(object):
         else:
             self._sam_build()
 
-    def _deploy_tables(self):
+    def _deploy_tables(self, local):
         for model in self._get_pynamo_models():
-            if self.local:
+            if local:
                 model.Meta.host = "http://localhost:4566"
 
-            # TODO: Should probably decide if this is how we want it to work.
             try:
-                if model.exists():
+                # TODO: Should probably decide if this is how we want it to work.
+                if model.exists() and local:
                     model.delete_table()
 
                 model.create_table(wait=True)
             except TableError as e:
-                if self.local:
+                if local:
                     print(
                         "Unable to connect to LocalStack to deploy DynamoDB tables. "
                         "Have you started LocalStack on your machine ('localstack start')?"
@@ -247,7 +247,7 @@ class Deployer(object):
 
     def deploy(self):
         self._build_template()
-        self._deploy_tables()
+        self._deploy_tables(False)
 
         # Creating S3 bucket for SAM.
         # TODO: Set this to create a random bucket if the name is taken or something.
@@ -293,7 +293,7 @@ class Deployer(object):
         elif method == "local":
             self._source_files()
             self._start_infra()
-            self._deploy_tables()
+            self._deploy_tables(True)
             self._start_api_local()
 
         else:
